@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.27 2004/01/05 17:36:00 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.32 2004/02/04 00:00:12 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -220,8 +220,7 @@ get_str_resource(enum res_type rtype, char *strval)
 
 
 /* Return the thousands separator string. For most locales, this is a 
- * comma. If this is the C locale, nl_langinfo(THOUSEP) returns an empty 
- * string, in which case we return ",".
+ * comma. 
  */
 
 const char *
@@ -234,7 +233,7 @@ get_tsep()
         tsep = g_locale_to_utf8(tsep, -1, NULL, NULL, NULL);
     }
 
-    if (tsep == NULL || tsep[0] == '\0') {
+    if (tsep == NULL) {
         return(",");
     } else {
         return(tsep);
@@ -242,12 +241,12 @@ get_tsep()
 }
 
 
-void
+static void
 init_constant(int n, gchar *value)
 {
     gchar *str = g_strdup(value);
 
-    MPstr_to_num(str, DEC, v->MPcon_vals[n]);
+    MPstr_to_num(str, DEC, TRUE, v->MPcon_vals[n]);
     g_free(str);
 }
 
@@ -255,7 +254,6 @@ init_constant(int n, gchar *value)
 void
 init_vars()    /* Setup default values for various variables. */
 {
-    char *loc_radix;
     int acc, i, n, size;
 
     v->accuracy      = 9;      /* Initial accuracy. */
@@ -279,8 +277,6 @@ init_vars()    /* Setup default values for various variables. */
 
     read_str(&v->iconlabel, _("calculator"));  /* Default icon label. */
 
-    loc_radix = (char *) v->radix;
-    v->radix = ".";
     init_constant(0, "0.621");                 /* kms/hr <=> miles/hr. */
     init_constant(1, "1.4142135623");          /* square root of 2 */
     init_constant(2, "2.7182818284");          /* e */
@@ -291,7 +287,6 @@ init_vars()    /* Setup default values for various variables. */
     init_constant(7, "0.0353");                /* grams <=> ounce. */
     init_constant(8, "0.948");                 /* Kjoules <=> BTU's. */
     init_constant(9, "0.0610");                /* cms3 <=> inches3. */
-    v->radix = loc_radix;
 
     n = 0;
     for (i = 0; i < MAXREGS; i++) {
