@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.110 2004/01/26 17:30:14 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.114 2004/02/09 15:56:45 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -288,6 +288,7 @@ about_cb(GtkWidget *widget, gpointer data)
             NULL
         };
         const gchar *documenters[] = {
+            "Sun Microsystems",
             NULL
         };
         const gchar *translator_credits = _("translator_credits");
@@ -1923,6 +1924,7 @@ set_error_state(int error)
     SET_MENUBAR_ITEM_STATE(M_FIN,    !v->error); 
     SET_MENUBAR_ITEM_STATE(M_SCI,    !v->error); 
     SET_MENUBAR_ITEM_STATE(M_ZEROES, !v->error); 
+    SET_MENUBAR_ITEM_STATE(M_TSEP,   !v->error); 
     SET_MENUBAR_ITEM_STATE(M_REGS,   !v->error); 
     SET_MENUBAR_ITEM_STATE(M_ABOUT,  !v->error);
 }
